@@ -38,7 +38,7 @@ class BuilderFiQuS:
                 if not roxie_data:
                     raise Exception(f'Cannot build model instantly without providing RoxieData as input roxie_data')
                 self.buildDataMultipole(model_data, roxie_data, flag_plot_all)
-            elif model_data.GeneralParameters.magnet_type == 'CCT':
+            elif model_data.GeneralParameters.magnet_type == 'CCT_straight':
                 self.buildDataCCT(model_data)
             else:
                 raise Exception(f'Magnet type: {model_data.GeneralParameters.magnet_type} is incompatible with FiQuS.')
@@ -58,16 +58,16 @@ class BuilderFiQuS:
         self.data_FiQuS.magnet.postproc.winding_order = model_data.CoilWindings.CCT_straight.winding_order
 
         # fqpls
-        self.data_FiQuS.magnet.geometry.fqpls.fndpls = model_data.Quench_Protection.FQPLs.fndpls
-        self.data_FiQuS.magnet.geometry.fqpls.fwhs = model_data.Quench_Protection.FQPLs.fwhs
-        self.data_FiQuS.magnet.geometry.fqpls.fwws = model_data.Quench_Protection.FQPLs.fwws
-        self.data_FiQuS.magnet.geometry.fqpls.n_sbs = model_data.Quench_Protection.FQPLs.n_sbs
-        self.data_FiQuS.magnet.geometry.fqpls.names = model_data.Quench_Protection.FQPLs.names
-        self.data_FiQuS.magnet.geometry.fqpls.r_bs = model_data.Quench_Protection.FQPLs.r_bs
-        self.data_FiQuS.magnet.geometry.fqpls.r_ins = model_data.Quench_Protection.FQPLs.r_ins
-        self.data_FiQuS.magnet.geometry.fqpls.thetas = model_data.Quench_Protection.FQPLs.thetas
-        self.data_FiQuS.magnet.geometry.fqpls.z_ends = model_data.Quench_Protection.FQPLs.z_ends
-        self.data_FiQuS.magnet.geometry.fqpls.z_starts = model_data.Quench_Protection.FQPLs.z_starts
+        self.data_FiQuS.magnet.geometry.fqpls.fndpls = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.fndpls, model_data.Quench_Protection.FQPLs.enabled) if flag]
+        self.data_FiQuS.magnet.geometry.fqpls.fwhs = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.fwhs, model_data.Quench_Protection.FQPLs.enabled) if flag]
+        self.data_FiQuS.magnet.geometry.fqpls.fwws = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.fwws, model_data.Quench_Protection.FQPLs.enabled) if flag]
+        self.data_FiQuS.magnet.geometry.fqpls.n_sbs = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.n_sbs, model_data.Quench_Protection.FQPLs.enabled) if flag]
+        self.data_FiQuS.magnet.geometry.fqpls.names = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.names, model_data.Quench_Protection.FQPLs.enabled) if flag]
+        self.data_FiQuS.magnet.geometry.fqpls.r_bs = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.r_bs, model_data.Quench_Protection.FQPLs.enabled) if flag]
+        self.data_FiQuS.magnet.geometry.fqpls.r_ins = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.r_ins, model_data.Quench_Protection.FQPLs.enabled) if flag]
+        self.data_FiQuS.magnet.geometry.fqpls.thetas = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.thetas, model_data.Quench_Protection.FQPLs.enabled) if flag]
+        self.data_FiQuS.magnet.geometry.fqpls.z_ends = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.z_ends, model_data.Quench_Protection.FQPLs.enabled) if flag]
+        self.data_FiQuS.magnet.geometry.fqpls.z_starts = [val for val, flag in zip(model_data.Quench_Protection.FQPLs.z_starts, model_data.Quench_Protection.FQPLs.enabled) if flag]
 
         # formers
         for key, value in model_data.Options_FiQuS.cct.geometry.formers.dict().items():       # for keys that are present in the model data (but not all keys in data FiQuS)
