@@ -302,7 +302,7 @@ def lookupWindings(key: int, mode: str = 'data2ledet'):
     magnet_type = {
         'multipole': 0,
         'solenoid' : 1,
-        'CCT'      : 2,
+        'CCT_straight': 2,
         'busbar'   : 101
     }
 
