@@ -2,7 +2,6 @@ import os
 import sys
 from pathlib import Path
 
-# from steam_sdk.data.DataAnalysis import ModifyModel, AddAuxiliaryFile
 from steam_sdk.data.DataAnalysis import DataAnalysis
 from steam_sdk.parsers.ParserYAML import yaml_to_data
 from steam_sdk.parsers.ParserYAML import dict_to_yaml
@@ -11,9 +10,11 @@ from steam_sdk.analyses.AnalysisSTEAM import AnalysisSTEAM
 
 class DriverAnalysis:
 
-    def __init__(self, analysis_yaml_path: str = None):
+    def __init__(self, analysis_yaml_path: str = None, iterable_steps: list = None):
         self.analysis_yaml_path = analysis_yaml_path
         self.analysis_data = yaml_to_data(analysis_yaml_path, DataAnalysis)
+        self.iterable_steps = iterable_steps
+
         path_dakota_python = os.path.join(Path(self.analysis_data.PermanentSettings.Dakota_path).parent.parent, 'share\dakota\Python')
         print('path_dakota_python:        {}'.format(path_dakota_python))
         sys.path.insert(0, path_dakota_python)
@@ -32,15 +33,6 @@ class DriverAnalysis:
             variables.append(var)
             values.append(value)
 
-        # type_sequence = [self.analysis_data.AnalysisStepDefinition[step].type
-        #                  for step in self.analysis_data.AnalysisStepSequence]
-        # runs = [i for i, x in enumerate(type_sequence) if x == 'RunSimulation']
-        # last_make = len(type_sequence) - 1 - type_sequence[::-1].index('MakeModel')
-        # last_modify = len(type_sequence) - 1 - type_sequence[::-1].index('ModifyModel')
-        # last_modify_multiple = len(type_sequence) - 1 - type_sequence[::-1].index('ModifyModelMultipleVariables')
-        # modified_step = self.analysis_data.AnalysisStepDefinition[self.analysis_data.AnalysisStepSequence[
-        #     max(last_modify, last_modify_multiple)]]
-
         i = -1
         while (self.analysis_data.AnalysisStepDefinition[self.analysis_data.AnalysisStepSequence[i]].type
                not in ['ModifyModel', 'ModifyModelMultipleVariables']):
@@ -54,6 +46,8 @@ class DriverAnalysis:
             modified_step.variables_to_change = variables
             modified_step.variables_value = [[value] for value in values]
 
+        self.analysis_data.AnalysisStepSequence = self.iterable_steps
+
         dict_to_yaml(self.analysis_data.dict(), self.analysis_yaml_path)
 
     def drive(self):
