@@ -4,11 +4,12 @@ import os
 
 class DriverDakota:
 
-    def __init__(self, Dakota_path, analysis_yaml_path=None, dakota_input_folder=None, dakota_output_folder=None):
+    def __init__(self, Dakota_path, analysis_yaml_path=None, iterable_steps=None, dakota_output_folder=None):
 
         # Define settings file
         self.Dakota_path = Dakota_path
         self.analysis_yaml_path = analysis_yaml_path
+        self.iterable_steps = iterable_steps
         self.dakota_output_folder = dakota_output_folder
 
     def run(self, input_file_path):
@@ -19,8 +20,8 @@ class DriverDakota:
         """
         os.chdir(self.dakota_output_folder)
         with open('driver_link.py', 'w') as f:
-            f.write('from steam_sdk.parsims.ParsimDakota import ParsimDakota')
-            f.write(f'\nda = ParsimDakota(r"{self.analysis_yaml_path}")')
+            f.write('from steam_sdk.drivers.DriverAnalysis import DriverAnalysis')
+            f.write(f'\nda = DriverAnalysis(r"{self.analysis_yaml_path}", {self.iterable_steps})')
             f.write('\nda.drive()')
 
         subprocess.call([self.Dakota_path, '-i', input_file_path])
