@@ -1387,7 +1387,7 @@ class ParserRoxie:
         # self.ax.add_line(lines.Line2D([corner2[0], corner1[0]], [corner2[1], corner1[1]], color='red'))
         # self.ax.add_line(lines.Line2D([corner1[0], corner0[0]], [corner1[1], corner0[1]], color='red'))
         # plt.show()
-        if self.block.type == 2:
+        if self.block.type == 2 or self.block.nco == 1:
             block.block_corners.iL = pd.Coord(x=sigDig(corner0[0]), y=sigDig(corner0[1]))  # 1
             block.block_corners.oL = pd.Coord(x=sigDig(corner3[0]), y=sigDig(corner3[1]))  # 4
             block.block_corners.iR = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))  # 2
