@@ -789,7 +789,7 @@ def add_probe(probe_type: str, probe_variables: list, analysis_type: str):
         type = 'AC'
     elif analysis_type=='transient':
         type = 'TRAN'
-    if probe_type == 'standard':
+    if probe_type == 'standard' or probe_type == 'CSDF':
         formatted_text = f'.PRINT {type} FORMAT=PROBE'
     else:
         raise Exception('Probe entry has an unknown or not implemented type: {}.'.format(probe_type))
